The data contained in this directory are part of the `DREAM7 Parameter Estimation Challenge <http://www.the-dream-project.org/challenges/network-topology-and-parameter-inference-challenge>`_

**The data of the challenges cannot be used for publication without the explicit permission of the data producers and the 
DREAM organization. Feel free to `contact us <http://www.the-dream-project.org/webform/contact-us>` about this.**


Data found in https://www.synapse.org/#!Synapse:syn2821735/wiki/71060


